@@ -5,7 +5,7 @@ use utf8;
 
 use Moo;
 
-our $VERSION = '0.002';
+our $VERSION = '0.003';
 
 with 'Parcel::Track::Role::Base';
 
@@ -64,13 +64,12 @@ sub track {
         );
 
         my $res = $http->get( $self->uri );
-        print $res->{content};
         unless ( $res->{success} ) {
             $result{result} = 'failed to get parcel tracking info from the site';
             return \%result;
         }
 
-        $content = $res->{content};
+        $content = Encode::encode_utf8( $res->{content} );
     }
     elsif ( my $wget = File::Which::which('wget') ) {
         my ( $stdout, $stderr, $exit ) = Capture::Tiny::capture {
@@ -158,7 +157,7 @@ Parcel::Track::KR::CJKorea - Parcel::Track driver for the CJ Korea Express (CJ 
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 SYNOPSIS
 
